.. swyft documentation master file, created by
   sphinx-quickstart on Thu Nov 12 11:23:08 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

.. toctree::
   :caption: Contents:
   :maxdepth: 2

   swyft
   install
   autodoc
   tutorial-notebooks
   videos
   contributing-link
   citation
